# comic-get.pl - Utility for fetching comics from the internet
# Copyright (C) 2004-2007 Tommi Saviranta <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

package ComicGet::Config;

use strict;
use warnings FATAL => 'all';

use ComicGet::Common;
use ComicGet::Files;
use ComicGet::Web;


# configuration
use vars qw($verbose $use_wget $target_dir @sources $home $pkg_lang $repo_pool);

$verbose = 0;
$use_wget = 0;
$target_dir = ".";
@sources = ();
$home = $ENV{"HOME"} . "/.comic-get";
$pkg_lang = "";

$repo_pool = "http://wnd.iki.fi/comic-get/repository-pool";



# internals
my $have_read = 0;
$use_wget = 0;



=item read
Read configuration file.
=cut
sub read() {
	return if ($have_read == 1);
	
	my $fn = &ComicGet::Files::config();
	open(FILE, "< $fn") or die("Cannot read \"$fn\": $!");
	while(<FILE>) {
		next if (/^\s*$/ || /^#/);
		chop;
		my ($key, $val) = /(.*?)\s*=\s*(.*)/;

		if ($key eq "source") {
			push(@sources, $val);
		} elsif ($key eq "target") {
			$target_dir = $val;
		} elsif ($key eq "repository-pool") {
			$repo_pool = $val;
		} else {
			print "Unknown configuration option: $_\n";
		}
	}
	close(FILE);

	$have_read = 1;
}


=item set_home
Set home directory.
=cut
sub set_home($) {
	$home = shift;
}


=item get_packages_files
Get packages.

r: Packages-files
=cut
sub get_packages_files() {
	&read();
	my @pkgs;
	foreach my $src (@sources) {
		my $id = &ComicGet::Index::id_by_source($src);
		push(@pkgs, &ComicGet::Files::packages($id));
	}
	return @pkgs;
}


1;
